package com.ruoyi.system.service;

import java.util.List;
import com.ruoyi.system.domain.BomanMaterial;

/**
 * 素材库Service接口
 * 
 * @author boman
 * @date 2023-11-02
 */
public interface IBomanMaterialService 
{
    /**
     * 查询素材库
     * 
     * @param materialId 素材库主键
     * @return 素材库
     */
    public BomanMaterial selectBomanMaterialByMaterialId(Long materialId);

    /**
     * 查询素材库列表
     * 
     * @param bomanMaterial 素材库
     * @return 素材库集合
     */
    public List<BomanMaterial> selectBomanMaterialList(BomanMaterial bomanMaterial);

    /**
     * 新增素材库
     * 
     * @param bomanMaterial 素材库
     * @return 结果
     */
    public int insertBomanMaterial(List<BomanMaterial> bomanMaterial);

    /**
     * 修改素材库
     * 
     * @param bomanMaterial 素材库
     * @return 结果
     */
    public int updateBomanMaterial(BomanMaterial bomanMaterial);

    /**
     * 批量删除素材库
     * 
     * @param materialIds 需要删除的素材库主键集合
     * @return 结果
     */
    public int deleteBomanMaterialByMaterialIds(Long[] materialIds);

    /**
     * 删除素材库信息
     * 
     * @param materialId 素材库主键
     * @return 结果
     */
    public int deleteBomanMaterialByMaterialId(Long materialId);
}
